@@ -1,4 +1,4 @@
-version = "0.0.21"
+version = "0.0.25"
 author = "RedHog (Egil Moeller)"
 author_email = "egil.moller@freecode.no"
 license = "GPL"
@@ -7,4 +7,4 @@ name = "appomatic_userena"
 description = "Userena is a Django application that supplies your Django project with full account management."
 keywords = "appomatic django-userena"
 url = "http://www.django-userena.org/"
-install_requires = ['appomatic', 'django==1.3.1', 'django-userena']
+install_requires = ['django-userena']
